@@ -53,11 +53,10 @@ class EB_Boost(EasyBlock):
     @staticmethod
     def extra_options():
         """Add extra easyconfig parameters for Boost."""
-        extra_vars = [
-            ('boost_mpi', [False, "Build mpi boost module (default: False)", CUSTOM]),
-            ('toolset', [None, "Toolset to use for Boost configuration ('--with-toolset fo bootstrap.sh')", CUSTOM]),
-        ]
-
+        extra_vars = {
+            'boost_mpi': [False, "Build mpi boost module", CUSTOM],
+            'toolset': [None, "Toolset to use for Boost configuration ('--with-toolset for bootstrap.sh')", CUSTOM],
+        }
         return EasyBlock.extra_options(extra_vars)
 
     def configure_step(self):
