@@ -47,15 +47,11 @@ class ConfigureMake(EasyBlock):
     @staticmethod
     def extra_options(extra_vars=None):
         """Extra easyconfig parameters specific to ConfigureMake."""
-
-        # using [] as default value is a bad idea, so we handle it this way
-        if extra_vars == None:
-            extra_vars = []
-
-        extra_vars.extend([
-                           ('tar_config_opts', [False, "Override tar settings as determined by configure.", CUSTOM]),
-                           ('prefix_opt', ['--prefix=', "Prefix command line option for configure script", CUSTOM]),
-                          ])
+        extra_vars = dict(EasyBlock.extra_options(extra_vars))
+        extra_vars.update({
+            'tar_config_opts': [False, "Override tar settings as determined by configure.", CUSTOM],
+            'prefix_opt': ['--prefix=', "Prefix command line option for configure script", CUSTOM],
+        })
         return EasyBlock.extra_options(extra_vars)
 
     def configure_step(self, cmd_prefix=''):
