@@ -18,6 +18,7 @@ EasyBuild support for building SAMtools (SAM - Sequence Alignment/Map), implemen
 """
 import os
 import shutil
+from distutils.version import LooseVersion
 
 from easybuild.easyblocks.generic.configuremake import ConfigureMake
 
@@ -37,7 +38,15 @@ class EB_SAMtools(ConfigureMake):
                           "misc/novo2sam.pl", "misc/psl2sam.pl", "misc/sam2vcf.pl", "misc/samtools.pl",
                           "misc/soap2sam.pl", "misc/varfilter.py", "misc/wgsim_eval.pl",
                           "misc/zoom2sam.pl", "misc/md5sum-lite", "misc/md5fa", "misc/maq2sam-short",
-                          "misc/maq2sam-long", "misc/wgsim", "misc/seqtk", "samtools"]
+                          "misc/maq2sam-long", "misc/wgsim", "samtools"]
+        if LooseVersion(self.version) <= LooseVersion('0.1.18'):
+            # seqtk is no longer there in v0.1.19
+            self.bin_files += ["misc/seqtk"]
+        elif LooseVersion(self.version) >= LooseVersion('0.1.19'):
+            # new tools in v0.1.19
+            self.bin_files += ["misc/ace2sam", "misc/bamcheck","misc/plot-bamcheck","misc/r2plot.lua",
+                               "misc/vcfutils.lua"]
+
         self.lib_files = ["libbam.a"]
         self.include_files = ["bam.h", "bam2bcf.h", "bam_endian.h", "bgzf.h", "errmod.h", "faidx.h", "kaln.h",
                               "khash.h", "klist.h", "knetfile.h", "kprobaln.h", "kseq.h", "ksort.h", "kstring.h",
